@@ -1,5 +1,5 @@
 /* vmlookup.c - vmailmgr CVM lookup routines
- * Copyright (C)2008  Bruce Guenter <bruce@untroubled.org>
+ * Copyright (C) 2010  Bruce Guenter <bruce@untroubled.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -90,7 +90,13 @@ int lookup_virtuser(void)
   str_lower(&virtuser);
   /* Found a virtual user, authenticate it. */
   if (chdir(vmuser.homedir.s) == -1) return CVME_IO;
-  if ((fd = open(pwfile, O_RDONLY)) == -1) return CVME_IO;
+  if ((fd = open(pwfile, O_RDONLY)) == -1) {
+    if (errno == ENOENT) {
+      cvm_module_fact_uint(CVM_FACT_OUTOFSCOPE, 1);
+      return CVME_PERMFAIL;
+    }
+    return CVME_IO;
+  }
   cdb_init(&cdb, fd);
   switch (cdb_get(&cdb, &virtuser, &vpwdata)) {
   case -1:
